Enums
- Value
- A value taken from a channel.
- Value
Series - A series of values. Mirrors the
nominal-streaming::PointsTypeenum. We avoid simply re-using that type to avoid coupling the app to the api too closely.
nominal-streaming::PointsType enum. We
avoid simply re-using that type to avoid coupling the app to the api too
closely.