ValueSeries

Enum ValueSeries 

pub enum ValueSeries {
    String(Vec<String>),
    Double(Vec<f64>),
    Integer(Vec<i64>),
}
A series of values. Mirrors the nominal-streaming::PointsType enum. We avoid simply re-using that type to avoid coupling the app to the api too closely.

Variants



String(Vec<String>)



Double(Vec<f64>)



Integer(Vec<i64>)

Implementations

Source

impl ValueSeries

pub fn get(&self, index: usize) -> Option<ValueRef<'_>>

pub fn transpose(self) -> Vec<ValueSeries>

Source

impl ValueSeries

pub fn iter(&self) -> ValueSeriesIter<'_>

pub fn iter_mut(&mut self) -> ValueSeriesIterMut<'_>

pub const fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn iter_numeric_as_f64(&self) -> Option<Box<dyn Iterator<Item = f64> + '_>>

Returns an iterator over numeric values cast to f64. Returns None for String variants.

pub fn truncate(&mut self, size: usize)