SampleTable

Struct SampleTable 

pub struct SampleTable { /* private fields */ }
A table of sample values, with timestamps indexing rows and channels indexing columns. Values are stored in column-major order.

Implementations

Source

impl SampleTable

pub fn new( timestamps: Vec<u64>, channels: Vec<ChannelStreamDescriptor>, values: Vec<ValueSeries>, ) -> Result<Self, SampleTableError>

Create a sample table from a list of timestamps, channels, and value series.

Each ValueSeries corresponds to the index-matched channel in channels, and must have the same length as timestamps.

pub fn from_single_channel( timestamp: u64, channel: ChannelStreamDescriptor, value: Value, ) -> Self

Create a sample table with a single timestamp and single values for a single channel.

pub fn from_multiple_channels( timestamp: u64, channels: Vec<ChannelStreamDescriptor>, values: Vec<Value>, ) -> Result<Self, SampleTableError>

Create a sample table with a single timestamp and single values for multiple channels.

pub fn iter_rows<'values>( &'values self, ) -> Result<impl Iterator<Item = RowRef<'values>>, SampleTableError>

Lazily-evaluated iterator over the rows of the sample table.

pub fn channels(&self) -> &[ChannelStreamDescriptor]

The channels in the sample table.

pub fn timestamps(&self) -> &[u64]

The timestamps in the sample table.

pub fn columns(&self) -> &[ValueSeries]

The columns in the sample table.

pub fn get_channel_values( &self, channel: &ChannelStreamDescriptor, ) -> Option<&ValueSeries>

The values for a given channel.

pub fn get_timestamped_channel_values( &self, channel: &ChannelStreamDescriptor, ) -> Option<impl Iterator<Item = (u64, ValueRef<'_>)>>

The values for a given channel and timestamp.

pub fn num_points(&self) -> usize

The number of points in the stream.

pub fn scale_channel( &mut self, channel: &ChannelStreamDescriptor, f: impl FnMut(ValueRef<'_>) -> Result<f64, String>, ) -> Result<(), SampleTableError>

Apply a scaling function to a channel’s values in place.

An error is returned if the channel specified is not present.

If any individual scaling operation fails, no further values are computed and the error is returned.