StreamData

Struct StreamData 

pub struct StreamData {
    pub stream_id: String,
    pub source: Option<String>,
    pub samples: SampleTable,
}

Fields

stream_id: String

Unique identifier for this stream.

source: Option<String>

Origin of this stream data, used for attribution in metrics.

This remains optional for wire compatibility. When absent, ingress rollups are still tracked under an explicit "unknown" source.

samples: SampleTable

The actual data being streamed.

Methods from Deref<Target = SampleTable>

pub fn iter_rows<'values>( &'values self, ) -> Result<impl Iterator<Item = RowRef<'values>>, SampleTableError>

Lazily-evaluated iterator over the rows of the sample table.

pub fn channels(&self) -> &[ChannelStreamDescriptor]

The channels in the sample table.

pub fn timestamps(&self) -> &[u64]

The timestamps in the sample table.

pub fn columns(&self) -> &[ValueSeries]

The columns in the sample table.

pub fn get_channel_values( &self, channel: &ChannelStreamDescriptor, ) -> Option<&ValueSeries>

The values for a given channel.

pub fn get_timestamped_channel_values( &self, channel: &ChannelStreamDescriptor, ) -> Option<impl Iterator<Item = (u64, ValueRef<'_>)>>

The values for a given channel and timestamp.

pub fn num_points(&self) -> usize

The number of points in the stream.

pub fn scale_channel( &mut self, channel: &ChannelStreamDescriptor, f: impl FnMut(ValueRef<'_>) -> Result<f64, String>, ) -> Result<(), SampleTableError>

Apply a scaling function to a channel’s values in place.

An error is returned if the channel specified is not present.

If any individual scaling operation fails, no further values are computed and the error is returned.